Clock class

Constructors

Clock({int? contents, double? biasNanos, double? biasUncertaintyNanos, double? driftNanosPerSecond, double? driftUncertaintyNanosPerSecond, int? fullBiasNanos, int? hardwareClockDiscontinuityCount, int? leapSecond, int? timeNanos, double? timeUncertaintyNanos})
Clock.fromJson(Map<String, dynamic> json)
factory

Properties

biasNanos → double?
final
biasUncertaintyNanos → double?
final
contents → int?
final
driftNanosPerSecond → double?
final
driftUncertaintyNanosPerSecond → double?
final
fullBiasNanos → int?
final
hardwareClockDiscontinuityCount → int?
final
hashCode → int
The hash code for this object.
no setterinherited
leapSecond → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeNanos → int?
final
timeUncertaintyNanos → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited