Status class

Constructors

Status({double? azimuthDegrees, double? carrierFrequencyHz, double? cn0DbHz, int? constellationType, double? elevationDegrees, int? svid, bool? hasAlmanacData, bool? hasCarrierFrequencyHz, bool? hasEphemerisData, bool? usedInFix})
Status.fromJson(Map<String, dynamic> json)
factory

Properties

azimuthDegrees ↔ double?
getter/setter pair
carrierFrequencyHz ↔ double?
getter/setter pair
cn0DbHz ↔ double?
getter/setter pair
constellationType ↔ int?
getter/setter pair
elevationDegrees ↔ double?
getter/setter pair
hasAlmanacData ↔ bool?
getter/setter pair
hasCarrierFrequencyHz ↔ bool?
getter/setter pair
hasEphemerisData ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
svid ↔ int?
getter/setter pair
usedInFix ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited